==> apache-james-mailbox-api-3.3.0-sources.jar: org/apache/james/mailbox/events/Event.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.events;

import java.util.Objects;
import java.util.UUID;

import org.apache.james.core.User;

import com.google.common.base.MoreObjects;
import com.google.common.base.Preconditions;

public interface Event {

    class EventId {
        public static EventId of(UUID uuid) {
            return new EventId(uuid);
        }

        public static EventId random() {
            return new EventId(UUID.randomUUID());
        }

        public static EventId of(String serialized) {
            return of(UUID.fromString(serialized));
        }

        private final UUID id;

        private EventId(UUID id) {
            Preconditions.checkNotNull(id);
            this.id = id;
        }

        public UUID getId() {
            return id;
        }

        @Override
        public final boolean equals(Object o) {
            if (o instanceof EventId) {
                EventId eventId = (EventId) o;

                return Objects.equals(this.id, eventId.id);
            }
            return false;
        }

        @Override
        public final int hashCode() {
            return Objects.hash(id);
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(this)
                .add("id", id)
                .toString();
        }
    }

    User getUser();

    boolean isNoop();

    EventId getEventId();
}

==> apache-james-mailbox-api-3.5.0-sources.jar: org/apache/james/mailbox/events/Event.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.events;

import java.util.Objects;
import java.util.UUID;

import org.apache.james.core.Username;

import com.google.common.base.MoreObjects;
import com.google.common.base.Preconditions;

public interface Event {

    class EventId {
        public static EventId of(UUID uuid) {
            return new EventId(uuid);
        }

        public static EventId random() {
            return new EventId(UUID.randomUUID());
        }

        public static EventId of(String serialized) {
            return of(UUID.fromString(serialized));
        }

        private final UUID id;

        private EventId(UUID id) {
            Preconditions.checkNotNull(id);
            this.id = id;
        }

        public UUID getId() {
            return id;
        }

        @Override
        public final boolean equals(Object o) {
            if (o instanceof EventId) {
                EventId eventId = (EventId) o;

                return Objects.equals(this.id, eventId.id);
            }
            return false;
        }

        @Override
        public final int hashCode() {
            return Objects.hash(id);
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(this)
                .add("id", id)
                .toString();
        }
    }

    Username getUsername();

    boolean isNoop();

    EventId getEventId();
}
